@@ -193,18 +193,15 @@ fallback_shape (PangoEngineShape *engine,
       gunichar mirrored_ch;
       PangoGlyph index;
       char buf[6];
-      const char *input;
 
       wc = g_utf8_get_char (p);
 
-      input = p;
       if (analysis->level % 2)
 	if (pango_get_mirror_char (wc, &mirrored_ch))
 	  {
 	    wc = mirrored_ch;
 	    
 	    g_unichar_to_utf8 (wc, buf);
-	    input = buf;
 	  }
 
       if (pango_is_zero_width (wc))
@@ -274,7 +271,8 @@ arabic_engine_shape (PangoEngineShape *engine,
 
   fc_font = PANGO_FC_FONT (font);
   face = pango_fc_font_lock_face (fc_font);
-  g_return_if_fail (face != NULL);
+  if (!face)
+    return;
 
   ruleset = get_ruleset (face);
   if (!ruleset)
@@ -301,18 +299,15 @@ arabic_engine_shape (PangoEngineShape *engine,
       gunichar mirrored_ch;
       PangoGlyph index;
       char buf[6];
-      const char *input;
 
       wc = g_utf8_get_char (p);
 
-      input = p;
       if (analysis->level % 2)
 	if (pango_get_mirror_char (wc, &mirrored_ch))
 	  {
 	    wc = mirrored_ch;
 	    
 	    g_unichar_to_utf8 (wc, buf);
-	    input = buf;
 	  }
 
       if (pango_is_zero_width (wc))	/* Zero-width characters */
@@ -369,7 +364,7 @@ arabic_engine_fc_class_init (PangoEngineShapeClass *class)
 }
 
 PANGO_ENGINE_SHAPE_DEFINE_TYPE (ArabicEngineFc, arabic_engine_fc,
-				arabic_engine_fc_class_init, NULL);
+				arabic_engine_fc_class_init, NULL)
 
 void 
 PANGO_MODULE_ENTRY(init) (GTypeModule *module)
